@@ -1,19 +1,17 @@
-use Image::DS9;
+#! perl
+
+use Test::Deep;
+
+use t::TestServer;
 
 our $verbose = 0;
 
-sub start_up
-{
+sub start_up  {
 
-  my $ds9 = Image::DS9->new( { Server => 'ImageDS9', verbose => $verbose });
-  unless ( $ds9->nservers )
-  {
-    system( "ds9 -title ImageDS9 &" );
-    $ds9->wait() or die( "unable to connect to DS9\n" );
-  }
-  
-  $ds9->raise();
-  $ds9;
+    my $ds9 = t::TestServer->new( $verbose );
+
+    $ds9->raise();
+    return $ds9;
 }
 
 sub clear
@@ -25,15 +23,12 @@ sub clear
 }
 
 
-# need this to get around bugs in ds9
 sub load_events
 {
   my $ds9 = shift;
 
-  eval {
-    $ds9->file( cwd() . "/snooker.fits.gz", { extname => 'raytrace', 
-					   bin => [ 'rt_x', 'rt_y' ] } );
-  };
+  $ds9->file( 'data/snooker.fits.gz', { extname => 'raytrace',
+					bin => [ 'rt_x', 'rt_y' ] } );
   $ds9->bin( factor => 0.025 );
   $ds9->zoom( 0 );
 }
@@ -50,7 +45,7 @@ sub test_stuff
     while ( my ( $subcmd, $args ) = splice( @$subcmds, 0, 2 ) )
     {
       my @subcmd = ( 'ARRAY' eq ref $subcmd ? @$subcmd : $subcmd );
-      $subcmd = join( ' ', @$subcmd) if 'ARRAY' eq ref $subcmd;
+      $subcmd = join( ' ', @subcmd);
 
       $args = [ $args ] unless 'ARRAY' eq ref $args;
 
@@ -60,15 +55,15 @@ sub test_stuff
 	$ret = $ds9->$cmd(@subcmd);
       };
 
-      print($@) && fail( "$cmd $subcmd" ) if $@;
+      diag($@) && fail( "$cmd $subcmd" ) if $@;
 
       if ( ! ref($ret) && 1 == @$args )
       {
-	ok( $ret eq $args->[0], "$cmd $subcmd" );
+	is( $ret, $args->[0], join( " ", $cmd, $subcmd,  @$args ) );
       }
       elsif ( @$ret == @$args )
       {
-	ok ( eq_array( $ret, $args ), "$cmd $subcmd" );
+	cmp_deeply( $ret, $args,  "$cmd $subcmd" );
       }
       else
       {
